Exceptions — Prognostics Models Python Package 1.2.0 documentation

# Exceptions

Exceptions returned from prog_model fall into a few custom exception types, defined below. Catching any Prognostics Model Exception can be acomplished using try-except ProgModelException. Alternatively, a user can catch a specific exception type.

## Prognostics Model Exceptions

exception prog_models.ProgModelException

  Base Prognostics Model Exception

  with_traceback()

    Exception.with_traceback(tb) – set self.__traceback__ to tb and return self.

exception prog_models.ProgModelInputException

  Prognostics Input Exception - indicates the method input parameters were incorrect

  with_traceback()

    Exception.with_traceback(tb) – set self.__traceback__ to tb and return self.

exception prog_models.ProgModelTypeError

  Prognostics Type Error - indicates the model could not be constructed

  with_traceback()

    Exception.with_traceback(tb) – set self.__traceback__ to tb and return self.

Copyright © 2020 United States Government as represented by the Administrator of the National Aeronautics and Space Administration. All Rights Reserved.